#[allow(warnings)]
use dioxus::prelude::*;
fn main() {
    dioxus::web::launch(app);
}
#[allow(warnings)]
pub fn app(cx: Scope) -> Element {
    use tracing::info;
    use wasm_macro::*;
    console_error_panic_hook::set_once();
    tracing_wasm::set_as_global_default();

    cx.render(rsx! {
        div{
            onclick:move|_|{
                // location_assign!("/demo");
                // info!("{}",location_herf!());
                // location_reload!();
                let main_div = document_query_selector_all!(".main");
                match main_div.get(0){ //frist of NodeList
                    Some(div) => {
                        div.append_child(&document_create_element!("div").clone_node().unwrap());
                    },
                    None => {},
                }
                console_log!(element_inner_html!(".main"));
                // element_set_inner_html!(".main","<h1>hello</h1>")
            },
            class:"main",
            style{[include_str!("./style/index.css")]},
            "test"
            }
    })
}
